# Happy CI

happy-ci is a lightweight CI/CD program.

It comes along with a simple plugin system, aims to make CI/CD very happy ^_^.

 # Features will be implemented
 1. basic features of a ci runner.
 1. make it a cluster, including master and runner.
 1. a web based user interface
 
 # Notice
 this project is at it's very early age, use it at your own risk.